searchData={"items":[{"type":"module","title":"Provider","doc":"The `Provider` module provides a macro for generating RESTful CRUD routes\nfor a given Ecto schema in a Plug-based application.\n\nThe `mount` macro automatically creates routes for listing, showing, creating,\nupdating, and deleting resources. Custom routes can also be defined within the\n`do` block.","ref":"Provider.html"},{"type":"macro","title":"Provider.mount/2","doc":"The `mount/2` macro is used to generate RESTful CRUD routes for a specified\nschema. It accepts the following options:\n\n- `:path`: The base path where the routes will be mounted.\n- `:schema`: The Ecto schema module for which the routes are being generated.\n- `:functions`: A keyword list of custom handler functions for specific routes.\n  Available keys are `:list`, `:get`, `:create`, `:update`, and `:delete`.\n- `do`: The block where custom routes can be defined.","ref":"Provider.html#mount/2"},{"type":"macro","title":"Example - Provider.mount/2","doc":"mount \"/users\", schema: MyApp.Schema.User do\n      get \"/custom/endpoint\" do\n        send_resp(conn, 200, \"Custom endpoint\")\n      end\n    end\n\nThis will generate the following routes:\n\n- `GET /users`       - Lists all users.\n- `GET /users/:id`   - Shows a specific user.\n- `POST /users`      - Creates a new user.\n- `PUT /users/:id`   - Updates an existing user.\n- `DELETE /users/:id` - Deletes a specific user.\n\nThe `schema` module must implement the `Provider.Schema` behavior, which\nenforces the presence of a `changeset/2` function.","ref":"Provider.html#mount/2-example"},{"type":"behaviour","title":"Provider.Schema","doc":"","ref":"Provider.Schema.html"},{"type":"macro","title":"Provider.Schema.__using__/1","doc":"Ensures that the schema implements the `changeset/2` function.","ref":"Provider.Schema.html#__using__/1"},{"type":"callback","title":"Provider.Schema.changeset/2","doc":"","ref":"Provider.Schema.html#c:changeset/2"},{"type":"extras","title":"Schema Provider","doc":"# Schema Provider\n\nThe `Schema Provider` module is designed to simplify the process of creating RESTful CRUD routes for Ecto schemas in a Plug-based Elixir application. It automatically generates routes for listing, showing, creating, updating, and deleting resources, and also allows for custom route definitions.","ref":"readme.html"},{"type":"extras","title":"Installation - Schema Provider","doc":"To use `Provider` in your project, add it as a dependency in your `mix.exs`:\n\n```elixir\ndefp deps do\n  [\n    {:schema_provider, \"~> 0.0.1\"}\n  ]\nend\n```\n\nThen, run:\n\n```bash\nmix deps.get\n```","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - Schema Provider","doc":"You need to configure the Ecto Repo that `Provider` will use in your `config/config.exs` file:\n\n```elixir\nimport Config\n\nconfig :schema_provider, repo: MyApp.Repo\n```","ref":"readme.html#configuration"},{"type":"extras","title":"Usage - Schema Provider","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Defining a Schema - Schema Provider","doc":"To use the `Provider` module, your schema module must implement the `Provider.Schema` behavior, which requires defining a `changeset/2` function.\n\n```elixir\ndefmodule MyApp.Schema.User do\n  use Ecto.Schema\n  use Provider.Schema\n\n  import Ecto.Changeset\n\n  schema \"users\" do\n    field :name, :string\n    field :email, :string\n    timestamps()\n  end\n\n  @impl true\n  def changeset(user, attrs) do\n    user\n    |> cast(attrs, [:name, :email])\n    |> validate_required([:name, :email])\n  end\nend\n```","ref":"readme.html#defining-a-schema"},{"type":"extras","title":"Using the `mount` Macro - Schema Provider","doc":"The `mount/2` macro in the `Provider` module generates RESTful CRUD routes for a specified schema. It takes the following options:\n\n- `:path` - The base path where the routes will be mounted.\n- `:schema` - The Ecto schema module for which the routes are being generated.\n- `:functions` - (Optional) A keyword list of custom handler functions for specific routes.\n\n#### Example\n\n```elixir\ndefmodule MyApp.Router do\n  use Plug.Router\n  use Provider\n\n  plug :match\n  plug :dispatch\n\n  mount \"/users\", schema: MyApp.Schema.User do\n    get \"/custom/endpoint\" do\n      send_resp(conn, 200, \"Custom endpoint\")\n    end\n  end\n\n  match _ do\n    send_resp(conn, 404, \"Not Found\")\n  end\nend\n```\n\nThis will generate the following routes:\n\n- `GET /users` - Lists all users.\n- `GET /users/:id` - Shows a specific user.\n- `POST /users` - Creates a new user.\n- `PUT /users/:id` - Updates an existing user.\n- `DELETE /users/:id` - Deletes a specific user.\n\nYou can also define custom routes inside the `do` block.","ref":"readme.html#using-the-mount-macro"},{"type":"extras","title":"License - Schema Provider","doc":"This project is licensed under the MIT License.","ref":"readme.html#license"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}